==> classpath-0.90-generics.tar.gz: classpath-0.90-generics/java/lang/ProcessBuilder.java <==
/* ProcessBuilder.java - Represent spawned system process
   Copyright (C) 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.lang;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

public class ProcessBuilder
{
  private File directory = new File(System.getProperty("user.dir"));
  private List<String> command;
  // FIXME: make a copy.
  private Map<String, String> environment = System.getenv();
  private boolean redirect = false;

  public ProcessBuilder(List<String> command)
  {
    this.command = command;
  }

  public ProcessBuilder(String... command)
  {
    this.command = Arrays.asList(command);
  }

  public List<String> command()
  {
    return command;
  }

  public ProcessBuilder command(List<String> command)
  {
    this.command = command;
    return this;
  }

  public ProcessBuilder command(String... command)
  {
    this.command = Arrays.asList(command);
    return this;
  }

  public File directory()
  {
    return directory;
  }

  public ProcessBuilder directory(File directory)
  {
    this.directory = directory;
    return this;
  }

  public Map<String, String> environment()
  {
    return environment;
  }

  public boolean redirectErrorStream()
  {
    return redirect;
  }

  public ProcessBuilder redirectErrorStream(boolean redirect)
  {
    this.redirect = redirect;
    return this;
  }

  public Process start() throws IOException
  {
    SecurityManager sm = SecurityManager.current; // Be thread-safe!
    if (sm != null)
      sm.checkExec(command.get(0));
    return VMProcess.exec(command, environment, directory, redirect);
  }
}

==> classpath-0.91-generics.tar.gz: classpath-0.91-generics/java/lang/ProcessBuilder.java <==
/* ProcessBuilder.java - Represent spawned system process
   Copyright (C) 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.lang;

import java.io.File;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

public final class ProcessBuilder
{
  private File directory = new File(System.getProperty("user.dir"));
  private List<String> command;
  // FIXME: make a copy.
  private Map<String, String> environment = System.getenv();
  private boolean redirect = false;

  public ProcessBuilder(List<String> command)
  {
    this.command = command;
  }

  public ProcessBuilder(String... command)
  {
    this.command = Arrays.asList(command);
  }

  public List<String> command()
  {
    return command;
  }

  public ProcessBuilder command(List<String> command)
  {
    this.command = command;
    return this;
  }

  public ProcessBuilder command(String... command)
  {
    this.command = Arrays.asList(command);
    return this;
  }

  public File directory()
  {
    return directory;
  }

  public ProcessBuilder directory(File directory)
  {
    this.directory = directory;
    return this;
  }

  public Map<String, String> environment()
  {
    return environment;
  }

  public boolean redirectErrorStream()
  {
    return redirect;
  }

  public ProcessBuilder redirectErrorStream(boolean redirect)
  {
    this.redirect = redirect;
    return this;
  }

  public Process start() throws IOException
  {
    SecurityManager sm = SecurityManager.current; // Be thread-safe!
    if (sm != null)
      sm.checkExec(command.get(0));
    return VMProcess.exec(command, environment, directory, redirect);
  }
}
